Add hipclang amdgcn functions

These are moving from hipclang in device library to hip headers. These are required for the functionality of HIPclang project.
This commit is contained in:
Aaron Enye Shi
2018-06-12 22:05:59 +00:00
parent fc80fb4ab3
commit c453b42bff
2 changed files with 192 additions and 14 deletions
+1 -8
View File
@@ -144,9 +144,6 @@ __device__ void* __hip_hc_memset(void* dst, uint8_t val, size_t size) {
return dst;
}
__device__ long long int clock64() { return (long long int)hc::__cycle_u64(); };
__device__ clock_t clock() { return (clock_t)hc::__cycle_u64(); };
// abort
__device__ void abort() { return hc::abort(); }
@@ -203,11 +200,7 @@ __host__ __device__ int max(int arg1, int arg2) {
return (int)(hc::precise_math::fmax((float)arg1, (float)arg2));
}
__device__ void* __get_dynamicgroupbaseptr() {
return hc::get_dynamic_group_segment_base_pointer();
}
__host__ void* __get_dynamicgroupbaseptr() { return nullptr; }
__device__ void __threadfence_system(void) { std::atomic_thread_fence(std::memory_order_seq_cst); }
__device__ void __threadfence_system(void) { std::atomic_thread_fence(std::memory_order_seq_cst); }